@@ -9,14 +9,14 @@ module Network.HTTP.Client.Connection
     , openSocketConnection
     , openSocketConnectionSize
     , makeConnection
+    , socketConnection
     ) where
 
 import Data.ByteString (ByteString, empty)
 import Data.IORef
 import Control.Monad
-import Control.Exception (throwIO)
 import Network.HTTP.Client.Types
-import Network.Socket (Socket, sClose, HostAddress)
+import Network.Socket (Socket, HostAddress)
 import qualified Network.Socket as NS
 import Network.Socket.ByteString (sendAll, recv)
 import qualified Control.Exception as E
@@ -27,7 +27,7 @@ import Data.Function (fix)
 connectionReadLine :: Connection -> IO ByteString
 connectionReadLine conn = do
     bs <- connectionRead conn
-    when (S.null bs) $ throwIO IncompleteHeaders
+    when (S.null bs) $ throwHttp IncompleteHeaders
     connectionReadLineWith conn bs
 
 -- | Keep dropping input until a blank line is found.
@@ -44,9 +44,9 @@ connectionReadLineWith conn bs0 =
         case S.break (== charLF) bs of
             (_, "") -> do
                 let total' = total + S.length bs
-                when (total' > 4096) $ throwIO OverlongHeaders
+                when (total' > 4096) $ throwHttp OverlongHeaders
                 bs' <- connectionRead conn
-                when (S.null bs') $ throwIO IncompleteHeaders
+                when (S.null bs') $ throwHttp IncompleteHeaders
                 go bs' (front . (bs:)) total'
             (x, S.drop 1 -> y) -> do
                 unless (S.null y) $! connectionUnread conn y
@@ -62,7 +62,6 @@ killCR bs
     | S.last bs == charCR = S.init bs
     | otherwise = bs
 
-
 -- | For testing
 dummyConnection :: [ByteString] -- ^ input
                 -> IO (Connection, IO [ByteString], IO [ByteString]) -- ^ conn, output, input
@@ -79,6 +78,9 @@ dummyConnection input0 = do
         , connectionClose = return ()
         }, atomicModifyIORef ioutput $ \output -> ([], output), readIORef iinput)
 
+-- | Create a new 'Connection' from a read, write, and close function.
+--
+-- @since 0.5.3
 makeConnection :: IO ByteString -- ^ read
                -> (ByteString -> IO ()) -- ^ write
                -> IO () -- ^ close
@@ -99,8 +101,7 @@ makeConnection r w c = do
     return $! Connection
         { connectionRead = do
             closed <- readIORef closedVar
-            when closed $
-              throwIO ConnectionClosed
+            when closed $ throwHttp ConnectionClosed
             join $ atomicModifyIORef istack $ \stack ->
               case stack of
                   x:xs -> (xs, return x)
@@ -108,24 +109,27 @@ makeConnection r w c = do
 
         , connectionUnread = \x -> do
             closed <- readIORef closedVar
-            when closed $
-              throwIO ConnectionClosed
+            when closed $ throwHttp ConnectionClosed
             atomicModifyIORef istack $ \stack -> (x:stack, ())
 
         , connectionWrite = \x -> do
             closed <- readIORef closedVar
-            when closed $
-              throwIO ConnectionClosed
+            when closed $ throwHttp ConnectionClosed
             w x
 
         , connectionClose = close
         }
 
-socketConnection :: Socket -> Int -> IO Connection
+-- | Create a new 'Connection' from a 'Socket'.
+--
+-- @since 0.5.3
+socketConnection :: Socket
+                 -> Int -- ^ chunk size
+                 -> IO Connection
 socketConnection socket chunksize = makeConnection
     (recv socket chunksize)
     (sendAll socket)
-    (sClose socket)
+    (NS.close socket)
 
 openSocketConnection :: (Socket -> IO ())
                      -> Maybe HostAddress
@@ -140,14 +144,14 @@ openSocketConnectionSize :: (Socket -> IO ())
                          -> String -- ^ host
                          -> Int -- ^ port
                          -> IO Connection
-openSocketConnectionSize tweakSocket chunksize hostAddress host port = do
+openSocketConnectionSize tweakSocket chunksize hostAddress' host' port' = do
     let hints = NS.defaultHints {
                           NS.addrFlags = [NS.AI_ADDRCONFIG]
                         , NS.addrSocketType = NS.Stream
                         }
-    addrs <- case hostAddress of
+    addrs <- case hostAddress' of
         Nothing ->
-            NS.getAddrInfo (Just hints) (Just host) (Just $ show port)
+            NS.getAddrInfo (Just hints) (Just host') (Just $ show port')
         Just ha ->
             return
                 [NS.AddrInfo
@@ -155,7 +159,7 @@ openSocketConnectionSize tweakSocket chunksize hostAddress host port = do
                  , NS.addrFamily = NS.AF_INET
                  , NS.addrSocketType = NS.Stream
                  , NS.addrProtocol = 6 -- tcp
-                 , NS.addrAddress = NS.SockAddrInet (toEnum port) ha
+                 , NS.addrAddress = NS.SockAddrInet (toEnum port') ha
                  , NS.addrCanonName = Nothing
                  }]
 
@@ -163,7 +167,7 @@ openSocketConnectionSize tweakSocket chunksize hostAddress host port = do
         E.bracketOnError
             (NS.socket (NS.addrFamily addr) (NS.addrSocketType addr)
                        (NS.addrProtocol addr))
-            (NS.sClose)
+            NS.close
             (\sock -> do
                 NS.setSocketOption sock NS.NoDelay 1
                 tweakSocket sock
